colour.models.dataset.max_rgb Module — Colour 0.3.0 documentation

# colour.models.dataset.max_rgb Module

## Max RGB Colourspace

Defines the Max RGB colourspace:

- `MAX_RGB_COLOURSPACE`.

See also

RGB Colourspaces IPython Notebook

References

[1] | http://www.hutchcolor.com/profiles/MaxRGB.zip (Last accessed 12 April 2014)

`colour.models.dataset.max_rgb.` `MAX_RGB_PRIMARIES` = array([[ 0.73413379, 0.26586621], [ 0.10039113, 0.89960887], [ 0.03621495, 0. ]])

  Max RGB colourspace primaries.

  MAX_RGB_PRIMARIES : ndarray, (3, 2)

`colour.models.dataset.max_rgb.` `MAX_RGB_WHITEPOINT` = (0.34567, 0.3585)

  Max RGB colourspace whitepoint.

  MAX_RGB_WHITEPOINT : tuple

`colour.models.dataset.max_rgb.` `MAX_RGB_TO_XYZ_MATRIX` = array([[ 0.85621356, 0.07699137, 0.03100707], [ 0.31007734, 0.68992266, 0. ], [ 0. , 0. , 0.82518828]])

  Max RGB colourspace to CIE XYZ colourspace matrix.

  MAX_RGB_TO_XYZ_MATRIX : array_like, (3, 3)

`colour.models.dataset.max_rgb.` `XYZ_TO_MAX_RGB_MATRIX` = array([[ 1.21712141, -0.13582369, -0.04573425], [-0.5470204 , 1.51048213, 0.0205547 ], [ 0. , 0. , 1.21184464]])

  CIE XYZ colourspace to Max RGB colourspace matrix.

  XYZ_TO_MAX_RGB_MATRIX : array_like, (3, 3)

`colour.models.dataset.max_rgb.` `MAX_RGB_TRANSFER_FUNCTION`(x)

  Transfer function from linear to Max RGB colourspace.

  MAX_RGB_TRANSFER_FUNCTION : object

`colour.models.dataset.max_rgb.` `MAX_RGB_INVERSE_TRANSFER_FUNCTION`(x)

  Inverse transfer function from Max RGB colourspace to linear.

  MAX_RGB_INVERSE_TRANSFER_FUNCTION : object

`colour.models.dataset.max_rgb.` `MAX_RGB_COLOURSPACE` = <colour.models.rgb_colourspace.RGB_Colourspace object at 0x102e24490>

  Max RGB colourspace.

  MAX_RGB_COLOURSPACE : RGB_Colourspace